pub enum DirtySpecializationSystems {
Clear,
CheckForChanges,
CheckForRemovals,
}Expand description
A SystemSet that contains all systems that mutate the
DirtySpecializations resource and other resources that wrap that type.
These systems must run in order.
Variants
Clear
Systems that clear out DirtySpecializations types in preparation for
a new frame.
CheckForChanges
Systems that add entities that need to be re-specialized to
DirtySpecializations.
CheckForRemovals
Systems that determine which entities need to be removed from render
phases and write the results to DirtySpecializations.
The set of entities that need to be removed from the render phases can
only be determined after all systems in
DirtySpecializationSystems::CheckForChanges have run. That’s because
these systems check RemovedComponents resources, and they have to be
able to distinguish between the case in which an entity was truly made
unrenderable and the case in which an entity appeared in a
RemovedComponents table simply because its material type changed.