pub struct ViewPendingQueues {
pub current_frame: HashSet<(Entity, MainEntity)>,
pub prev_frame: HashSet<(Entity, MainEntity)>,
}Expand description
Holds all entities that couldn’t be specialized and/or queued because their materials and/or other dependent resources hadn’t loaded yet for a single view.
See the documentation of PendingQueues for more information.
Fields
current_frame: HashSet<(Entity, MainEntity)>The entities that couldn’t be specialized and/or queued this frame.
We add to this list during pipeline specialization and queuing.
prev_frame: HashSet<(Entity, MainEntity)>The entities that we need to re-examine in this frame.
We attempt to specialize and queue entities in this list every frame, as long as those entities are still visible.